@@ -66,7 +66,7 @@ static void save_libfm_settings (void);
 static void save_lxterm_settings (void);
 static void save_libreoffice_settings (void);
 static void reset_to_defaults (void);
-static void on_set_defaults (GtkButton* btn, gpointer ptr);
+static void on_set_defaults (GtkButton *btn, gpointer ptr);
 
 /*----------------------------------------------------------------------------*/
 /* Function definitions                                                       */
@@ -276,7 +276,7 @@ static void defaults_gtk3 (void)
 
     for (dark = 0; dark < 2; dark++)
     {
-        sys_config_file = g_build_filename ("/usr/share/themes", dark ? DEFAULT_THEME_DARK : DEFAULT_THEME, "gtk-3.0/!(*-dark).css", NULL);
+        sys_config_file = g_build_filename ("/usr/share/themes", theme_name (dark), "gtk-3.0/!(*-dark).css", NULL);
 
         cmdbuf = g_strdup_printf ("bash -O extglob -c \"grep -hPo '(?<=@define-color\\stheme_selected_bg_color\\s)#[0-9A-Fa-f]{6}' %s 2> /dev/null\"", sys_config_file);
         res = get_string (cmdbuf);
@@ -474,33 +474,20 @@ void init_session (const char *theme)
 
 static void reset_to_defaults (void)
 {
-    const char *session_name = session ();
-    char *path, *lc_sess, *fname, *monname;
+    char *path, *monname;
     int i;
 
-    lc_sess = g_ascii_strdown (session_name, -1);
-    fname = g_strconcat (lc_sess, "-rc.xml", NULL);
-    path = g_build_filename (".config/openbox", fname, NULL);
-    delete_file (path);
-    g_free (path);
-    g_free (fname);
-    g_free (lc_sess);
-
-    path = g_build_filename (".config/lxsession", session_name, "desktop.conf", NULL);
-    delete_file (path);
-    g_free (path);
-
-    path = g_build_filename (".config/lxpanel", session_name, "panels/panel", NULL);
-    delete_file (path);
-    g_free (path);
+    delete_file (".config/openbox/rpd-rc.xml");
+    delete_file (".config/lxsession/rpd-x/desktop.conf");
+    delete_file (".config/lxpanel-pi/panels/panel");
+    delete_file (".config/wf-panel-pi/wf-panel-pi.ini");
+    delete_file (".config/pcmanfm/default/pcmanfm.conf");
 
     for (i = 0; i < ndesks; i++)
     {
-        fname = g_strdup_printf ("desktop-items-%d.conf", i);
-        path = g_build_filename (".config/pcmanfm", session_name, fname, NULL);
+        path = g_strdup_printf (".config/pcmanfm/default/desktop-items-%d.conf", i);
         delete_file (path);
         g_free (path);
-        g_free (fname);
 
         if (wm != WM_OPENBOX)
         {
@@ -508,24 +495,18 @@ static void reset_to_defaults (void)
 #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
             monname = gdk_screen_get_monitor_plug_name (gdk_display_get_default_screen (gdk_display_get_default ()), i);
 #pragma GCC diagnostic pop
-            fname = g_strdup_printf ("desktop-items-%s.conf", monname);
-            path = g_build_filename (".config/pcmanfm", session_name, fname, NULL);
+            path = g_strdup_printf (".config/pcmanfm/default/desktop-items-%s.conf", monname);
             delete_file (path);
             g_free (path);
-            g_free (fname);
             g_free (monname);
         }
     }
 
-    path = g_build_filename (".config/pcmanfm", session_name, "pcmanfm.conf", NULL);
+    path = g_build_filename (".local/share/themes", theme_name (LIGHT), "gtk-3.0/gtk.css", NULL);
     delete_file (path);
     g_free (path);
 
-    path = g_build_filename (".local/share/themes", DEFAULT_THEME, "gtk-3.0/gtk.css", NULL);
-    delete_file (path);
-    g_free (path);
-
-    path = g_build_filename (".local/share/themes", DEFAULT_THEME_DARK, "gtk-3.0/gtk.css", NULL);
+    path = g_build_filename (".local/share/themes", theme_name (DARK), "gtk-3.0/gtk.css", NULL);
     delete_file (path);
     g_free (path);
 
@@ -536,7 +517,7 @@ static void reset_to_defaults (void)
     delete_file (".config/labwc/themerc-override");
     delete_file (".gtkrc-2.0");
 
-    init_session (TEMP_THEME);
+    init_session (theme_name (TEMP));
 }
 
 void create_defaults (void)
@@ -544,7 +525,7 @@ void create_defaults (void)
     int i;
     // defaults for controls
 
-    // /etc/xdg/lxpanel/LXDE-pi/panels/panel
+    // /etc/xdg/lxpanel-pi/panels/panel
     defaults_lxpanel ();
 
     // /etc/xdg/lxsession/LXDE-pi/desktop.conf
@@ -576,7 +557,6 @@ void create_defaults (void)
 
     def_lg = def_sm = def_med;
 
-    def_lg.desktop_font = "PibotoLt 16";
     def_lg.icon_size = 52;
     def_lg.cursor_size = 36;
 
@@ -591,7 +571,6 @@ void create_defaults (void)
     def_lg.handle_width = 20;
     def_lg.scrollbar_width = 17;
 
-    def_sm.desktop_font = "PibotoLt 8";
     def_sm.icon_size = 20;
     def_sm.cursor_size = 24;
 
@@ -605,13 +584,24 @@ void create_defaults (void)
     def_sm.task_width = 150;
     def_sm.handle_width = 10;
     def_sm.scrollbar_width = 13;
+
+    if (trix_theme)
+    {
+        def_lg.desktop_font = "Nunito Sans Light 16";
+        def_sm.desktop_font = "Nunito Sans Light 8";
+    }
+    else
+    {
+        def_lg.desktop_font = "PibotoLt 16";
+        def_sm.desktop_font = "PibotoLt 8";
+    }
 }
 
 /*----------------------------------------------------------------------------*/
 /* Control handlers                                                           */
 /*----------------------------------------------------------------------------*/
 
-static void on_set_defaults (GtkButton* btn, gpointer ptr)
+static void on_set_defaults (GtkButton *btn, gpointer ptr)
 {
     int i;
 
@@ -661,6 +651,7 @@ static void on_set_defaults (GtkButton* btn, gpointer ptr)
     save_session_settings ();
     save_gtk3_settings ();
     save_panel_settings ();
+    save_greeter_settings ();
 
     // save application-specific config - we don't delete these files first...
     save_lxterm_settings ();
